@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -25,10 +25,6 @@
 #include <QObject>
 #include <KContacts/Addressee>
 
-namespace Grantlee {
-class Engine;
-}
-
 namespace KAddressBookGrantlee {
 class KADDRESSBOOK_GRANTLEE_EXPORT GrantleePrint : public PimCommon::GenericGrantleeFormatter
 {
